# Backlog

---

- Enhancement to Altair charts (e.g. tooltip, titles, etc.)
- Add support for 3 variables
- Refactor visual engine --- 'register' functions; framework finds all matching signatures
- Add history and series of commands to ce module
  - get_last
  - show_last
  - get_history
  - show_history
- Add more testing robustness - incorporate hypothesis
